@@ -3,7 +3,6 @@ OC.L10N.register(
     {
     "Auto detect failed. Please use manual mode." : "自动检测失败，请使用手动模式。",
     "Updating account failed: " : "更新账号失败：",
-    "Creating account failed: " : "创建账号失败：",
     "Embedded message %s" : "嵌入式消息 %s",
     "Important mail" : "重要邮件",
     "Unread mail" : "未读邮件",
@@ -21,7 +20,7 @@ OC.L10N.register(
     "Deleted messages are moved in:" : "已删除邮件被移动到：",
     "Auto" : "自动",
     "Name" : "姓名",
-    "Mail Address" : "邮箱",
+    "Mail address" : "邮箱",
     "Password" : "密码",
     "Manual" : "手动",
     "IMAP Settings" : "IMAP 设置",
@@ -39,6 +38,7 @@ OC.L10N.register(
     "SMTP Port" : "SMTP 端口",
     "SMTP User" : "SMTP 用户",
     "SMTP Password" : "SMTP 密码",
+    "Connecting" : "正在连接",
     "Save" : "保存",
     "Connect" : "连接",
     "Account settings" : "账号设置",
@@ -72,24 +72,23 @@ OC.L10N.register(
     "Select account" : "选择账号",
     "To" : "收件人",
     "Contact or email address …" : "联系人或邮箱地址...",
-    "+ Cc/Bcc" : "+ 抄送/密送",
     "Cc" : "抄送",
-    "No contacts found." : "未找到联系人。",
     "Bcc" : "密送",
+    "No contacts found." : "未找到联系人。",
     "Subject" : "主题",
     "Subject …" : "标题...",
     "This message came from a noreply address so your reply will probably not be read." : "标记的消息来自一个无法回复的地址，您的回复可能不会被阅读。",
     "The following recipients do not have a PGP key: {recipients}." : "以下收件人没有 PGP 密钥：{recipients}。",
     "Write message …" : "编写消息...",
-    "Cannot save draft because this account does not have a drafts mailbox configured." : "无法保存草稿，因为该账户没有配置草稿邮箱。 ",
     "Saving draft …" : "正在保存草稿 …",
     "Draft saved" : "草稿已保存",
+    "Discard & close draft" : "丢弃并关闭草稿",
     "Upload attachment" : "上传附件",
     "Add attachment from Files" : "从文件添加附件",
     "Enable formatting" : "启用格式化",
     "Request a read receipt" : "请求已读回执",
     "Encrypt message with Mailvelope" : "使用 Mailvelope 加密邮件",
-    "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "在寻找加密您邮件的方法吗？安装 Mailvelope 浏览器扩展！",
+    "Enter a date" : "输入日期",
     "Uploading attachments …" : "正在上传附件…",
     "Sending …" : "正在发送…",
     "Error sending your message" : "发送您的消息时出错",
@@ -98,7 +97,6 @@ OC.L10N.register(
     "Warning sending your message" : "对发送信息提出警告",
     "Send anyway" : "不论如何都要发送",
     "Message sent!" : "消息已发送！",
-    "Write another message" : "再写一条消息",
     "Add share link from {productName} Files" : "添加来自 {productName} 文件的共享链接",
     "Send" : "发送",
     "Encrypt and send" : "加密并发送",
@@ -117,21 +115,20 @@ OC.L10N.register(
     "No messages in this mailbox" : "此邮箱中没有消息",
     "No messages" : "没有消息",
     "Draft: " : "草稿: ",
-    "Mark unimportant" : "标记为不重要",
-    "Mark important" : "标记为重要",
-    "Mark unfavorite" : "取消收藏",
-    "Mark favorite" : "收藏",
-    "Mark unread" : "标记为未读",
-    "Mark read" : "标记为已读",
+    "Unfavorite" : "取消收藏",
+    "Favorite" : "收藏",
+    "Read" : "读取",
     "Mark not spam" : "标记为非垃圾邮件",
     "Mark as spam" : "标记为垃圾邮件",
     "Unselect" : "取消选择",
     "Select" : "选择",
     "Edit tags" : "编辑标签",
+    "Move" : "移动",
     "Move thread" : "移动线程",
-    "Create event" : "创建事件",
-    "Edit as new message" : "编辑为新消息",
+    "More actions" : "更多操作 ",
     "Delete thread" : "删除线程",
+    "Edit as new message" : "编辑为新消息",
+    "Create event" : "创建事件",
     "Blind copy recipients only" : "仅向收件人发送无信头副本",
     "No trash mailbox configured" : "没有配置垃圾邮箱",
     "Could not delete message" : "无法删除消息",
@@ -152,7 +149,7 @@ OC.L10N.register(
     "Event created" : "已创建事件",
     "Could not create event" : "无法建立事件",
     "Could not open mailbox" : "无法打开邮箱",
-    "Loading messages" : "正在加载消息",
+    "Loading messages …" : "正在加载邮件…",
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "正在为您的消息建立索引。 对于较大的邮箱，这可能需要更长的时间。",
     "Choose target mailbox" : "选择目标邮箱",
     "No more submailboxes in here" : "这里已经没有更多子邮箱",
@@ -170,9 +167,9 @@ OC.L10N.register(
     "Reply to sender only" : "只回复发送者",
     "Forward" : "转发",
     "Move message" : "移动消息",
+    "Delete message" : "删除消息",
     "View source" : "查看来源",
     "Download thread data for debugging" : "下载线程数据以进行调试",
-    "Delete message" : "删除消息",
     "Message source" : "消息来源",
     "Message body" : "消息正文",
     "Import into calendar" : "导入到日历",
@@ -192,7 +189,6 @@ OC.L10N.register(
     "Always show images from {domain}" : "始终显示来自 {domain} 的图片",
     "Message frame" : "消息框",
     "Quoted text" : "引用文字",
-    "Move" : "移动",
     "Moving" : "移动",
     "Moving thread" : "正在移动线程",
     "Moving message" : "正在移动消息",
@@ -228,14 +224,12 @@ OC.L10N.register(
     "An error occurred, unable to rename the mailbox." : "发生错误，无法重命名邮箱。",
     "_{total} message_::_{total} messages_" : ["{total} 条消息"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["总共 {total} 封邮件，{unread} 封未读邮件"],
-    "Not found" : "没有找到",
-    "Attachments were not copied. Please add them manually." : "附件没有被复制。请手动添加。",
-    "Could not load your draft" : "无法加载您的草稿",
-    "Could not load original message" : "无法加载初始消息",
     "No message selected" : "没有选择消息",
+    "Delete" : "删除",
     "Contacts with this address" : "使用此地址的联系人 ",
     "Add to Contact" : "添加到联系人",
     "New Contact" : "新联系人",
+    "Copy to clipboard" : "复制到剪贴板",
     "Contact name …" : "联系人姓名 …",
     "Add" : "新增",
     "Disabled" : "已禁用",
@@ -254,7 +248,6 @@ OC.L10N.register(
     "Signature …" : "签名...",
     "Place signature above quoted text" : "把签名放在引用文本上方",
     "Save signature" : "保存签名",
-    "Delete" : "删除",
     "Add default tags" : "添加默认标签",
     "Rename tag" : "重命名标签",
     "Saving new tag name …" : "保存新标签名中 …",
@@ -262,9 +255,11 @@ OC.L10N.register(
     "Unset" : "取消设置",
     "Add tag" : "添加标签",
     "Saving tag …" : "正在保存标签 …",
+    "Tag already exists" : "标签已存在",
     "An error occurred, unable to create the tag." : "发生了一个错误，无法创建标签",
     "An error occurred, unable to rename the tag." : "发生错误，无法重命名标签",
     "Could not load your message thread" : "无法加载您的消息线线程",
+    "Not found" : "没有找到",
     "Remove" : "删除",
     "No senders are trusted at the moment." : "当前没有发件人是受信任的",
     "Could not remove trusted sender {sender}" : "无法删除受信任的发件人 {sender} ",
@@ -351,7 +346,6 @@ OC.L10N.register(
     "Search" : "搜索",
     "Refresh" : "刷新",
     "Connect your mail account" : "连接您的邮件账号",
-    "Unexpected error during account creation" : "创建账号时发生意外错误",
     "Itinerary for {type} is not supported yet" : "尚不支持 {type} 类型的行程",
     "All" : "全部",
     "Archive" : "归档",
@@ -366,6 +360,8 @@ OC.L10N.register(
     "{from}\n{subject}" : "{from}\n{subject}",
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["来自 {from} 的 %n 条新消息"],
     "Nextcloud Mail" : "Nextcloud 邮件",
+    "Attachments were not copied. Please add them manually." : "附件没有被复制。请手动添加。",
+    "Message sent" : "消息已发送",
     "Could not load {tag}{name}{endtag}" : "无法加载 {tag}{name}{endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "加载 {tag}{name}{endtag} 时出现问题",
     "Could not load your message" : "无法加载您的消息",
