@@ -11,6 +11,7 @@ declare(strict_types=1);
  * @author Lukas Reschke <lukas@owncloud.com>
  * @author Thomas Imbreckx <zinks@iozero.be>
  * @author Thomas Müller <thomas.mueller@tmit.eu>
+ * @author Richard Steinmetz <richard@steinmetz.cloud>
  *
  * Mail
  *
@@ -73,7 +74,7 @@ class MessagesController extends Controller {
 	/** @var ItineraryService */
 	private $itineraryService;
 
-	/** @var string */
+	/** @var ?string */
 	private $currentUserId;
 
 	/** @var LoggerInterface */
@@ -123,7 +124,7 @@ class MessagesController extends Controller {
 								IMailManager $mailManager,
 								IMailSearch $mailSearch,
 								ItineraryService $itineraryService,
-								string $UserId,
+								?string $UserId,
 								$userFolder,
 								LoggerInterface $logger,
 								IL10N $l10n,
@@ -144,7 +145,6 @@ class MessagesController extends Controller {
 		$this->l10n = $l10n;
 		$this->mimeTypeDetector = $mimeTypeDetector;
 		$this->urlGenerator = $urlGenerator;
-		$this->mailManager = $mailManager;
 		$this->nonceManager = $nonceManager;
 		$this->trustedSenderService = $trustedSenderService;
 		$this->mailTransmission = $mailTransmission;
@@ -248,11 +248,10 @@ class MessagesController extends Controller {
 			$message->getUid(),
 			true
 		)->getFullMessage($id);
-		$json['itineraries'] = $this->itineraryService->extract(
-			$account,
-			$mailbox->getName(),
-			$message->getUid()
-		);
+		$itineraries = $this->itineraryService->getCached($account, $mailbox, $message->getUid());
+		if ($itineraries) {
+			$json['itineraries'] = $itineraries;
+		}
 		$json['attachments'] = array_map(function ($a) use ($id) {
 			return $this->enrichDownloadUrl(
 				$id,
@@ -272,6 +271,28 @@ class MessagesController extends Controller {
 		return $response;
 	}
 
+	/**
+	 * @NoAdminRequired
+	 * @TrapError
+	 *
+	 * @param int $id
+	 *
+	 * @return JSONResponse
+	 *
+	 * @throws ClientException
+	 */
+	public function getItineraries(int $id): JSONResponse {
+		try {
+			$message = $this->mailManager->getMessage($this->currentUserId, $id);
+			$mailbox = $this->mailManager->getMailbox($this->currentUserId, $message->getMailboxId());
+			$account = $this->accountService->find($this->currentUserId, $mailbox->getAccountId());
+		} catch (DoesNotExistException $e) {
+			return new JSONResponse([], Http::STATUS_FORBIDDEN);
+		}
+
+		return new JsonResponse($this->itineraryService->extract($account, $mailbox, $message->getUid()));
+	}
+
 	private function isSenderTrusted(Message $message): bool {
 		$from = $message->getFrom();
 		$first = $from->first();
